![](https://github.com/VUIIS/dax/blob/master/docs/images/dax_logo.png)
Distributed Automation for XNAT
===

# Install DAX

Install it with:

~~~~~~~~
pip install dax
~~~~~~~~

Use --upgrade to overwrite previous installation

To install current main branch:

~~~~~~~~
pip install git+https://github.com/VUIIS/dax.git --upgrade
~~~~~~~~

or a specific branch:

~~~~~~~~
pip install git+https://github.com/VUIIS/dax.git@branch_name --upgrade
~~~~~~~~

# Docs
[![Documentation Status](https://readthedocs.org/projects/dax/badge/?version=latest)](http://dax.readthedocs.org/en/latest/?badge=latest)

<!-- Disabled since masijenkins is no longer in use for this purpose 
# Build
[![Build Status](http://masijenkins.vuse.vanderbilt.edu:8080/buildStatus/icon?job=Build_DAX)](http://masijenkins.vuse.vanderbilt.edu:8080/job/Build_DAX/)
-->

<!-- Disabled since spiders are now repos on github
# Spiders
All of our piplines are available on NITRC. [Come join our team!](https://www.nitrc.org/projects/masimatlab)
-->
